pub fn detect_provider(model: &str, base_url: &str) -> ProviderKindExpand description
Detect the right provider from a model name or base URL.
pub fn detect_provider(model: &str, base_url: &str) -> ProviderKindDetect the right provider from a model name or base URL.