pub fn build_system_prompt(tools: &ToolRegistry, state: &AppState) -> StringExpand description
Build the system prompt from tool definitions, app state, and memory.
pub fn build_system_prompt(tools: &ToolRegistry, state: &AppState) -> StringBuild the system prompt from tool definitions, app state, and memory.