Query source tagging.
Every API call is tagged with its originating source so costs and errors can be attributed correctly.
Enums
- Query
Source - Identifies where an API call originated from.
Query source tagging.
Every API call is tagged with its originating source so costs and errors can be attributed correctly.