Background task execution.
Manages tasks that run asynchronously while the user continues interacting with the agent. Tasks output to files and notify the user when complete.
Structs
- Task
Info - Metadata for a running or completed background task.
- Task
Manager - Manages background task lifecycle.
Enums
- Task
Status - Status of a background task.
Type Aliases
- TaskId
- Unique task identifier.