CacheTracker

Struct CacheTracker 

pub struct CacheTracker {
    pub total_cache_writes: u64,
    pub total_cache_reads: u64,
    pub call_count: u64,
    pub hit_count: u64,
    pub break_count: u64,
    /* private fields */
}
Tracks cache performance across multiple API calls.

Fields

total_cache_writes: u64

Total cache creation tokens (cache misses that create new entries).

total_cache_reads: u64

Total cache read tokens (cache hits).

call_count: u64

Number of API calls observed.

hit_count: u64

Number of calls that had any cache reads (hits).

break_count: u64

Number of calls where cache writes exceeded reads (likely break).

Implementations

Source

impl CacheTracker

pub fn new() -> Self

pub fn update_fingerprint( &mut self, system_prompt: &str, tool_count: usize, ) -> bool

Update the fingerprint of the cacheable request prefix. Call before each API request. Returns true if the fingerprint changed (indicating the cache will likely break).

pub fn record(&mut self, usage: &Usage) -> CacheEvent

Record usage from an API call and detect cache breaks.

pub fn hit_rate(&self) -> f64

Cache hit rate as a percentage (0-100).

pub fn estimated_savings(&self) -> f64

Estimated cost savings from cache hits. Cache reads are ~10% the cost of cache writes.