canonical_root

Function canonical_root 

pub async fn canonical_root(cwd: &Path) -> Option<String>
Resolve the canonical repository root, following worktree links.

If the current directory is inside a worktree, this returns the path to the main repository (not the worktree checkout).