Module git_ops

Module git_ops 

Git operation detection from command output.

Parses bash tool output to detect git commits, PR creates, branch operations, and other git events. Used for tracking and telemetry.

Structs

GitOperation
A detected git operation.

Enums

GitOpKind

Functions

detect_git_ops
Detect git operations from a command string and its output.