pub fn detect_git_ops(command: &str, output: &str) -> Vec<GitOperation>Expand description
Detect git operations from a command string and its output.
pub fn detect_git_ops(command: &str, output: &str) -> Vec<GitOperation>Detect git operations from a command string and its output.