Module telemetry

Module telemetry 

Telemetry and observability attributes.

Structured attributes attached to API calls and tool executions for performance monitoring and debugging. These are local-only (no data is sent externally) and can be consumed by logging, tracing, or exported via OpenTelemetry.

Modules

attrs
Common attribute keys.

Structs

TelemetrySpan
Structured attributes for a single API call or tool execution.

Functions

api_call_span
Build telemetry attributes for an API call.
record_usage
Record usage into a span.
tool_span
Build telemetry attributes for a tool execution.