pub fn parse_bash(command: &str) -> Option<ParsedCommand>Expand description
Parse a bash command string into a structured representation.
pub fn parse_bash(command: &str) -> Option<ParsedCommand>Parse a bash command string into a structured representation.