PowerShell tool for Windows environments.
Provides PowerShell command execution on Windows. On non-Windows platforms, this tool is disabled and hidden from the registry.
PowerShell tool for Windows environments.
Provides PowerShell command execution on Windows. On non-Windows platforms, this tool is disabled and hidden from the registry.