SendMessage tool: communicate between agents.
Allows one agent to send a message to another running agent by ID or name. Used for coordination in multi-agent workflows.
SendMessage tool: communicate between agents.
Allows one agent to send a message to another running agent by ID or name. Used for coordination in multi-agent workflows.