ToolSearch tool: discover deferred tools by keyword.
Allows the agent to search for tools that aren’t loaded by default.
Supports direct selection (select:ToolName) and keyword search.
ToolSearch tool: discover deferred tools by keyword.
Allows the agent to search for tools that aren’t loaded by default.
Supports direct selection (select:ToolName) and keyword search.