pub fn watch_config( on_reload: impl Fn(Config) + Send + 'static, ) -> Option<JoinHandle<()>>
Watch config files for changes and reload when modified. Returns a handle that can be dropped to stop watching.