Module background

Module background 

Background task execution.

Manages tasks that run asynchronously while the user continues interacting with the agent. Tasks output to files and notify the user when complete.

Structs

TaskInfo
Metadata for a running or completed background task.
TaskManager
Manages background task lifecycle.

Enums

TaskStatus
Status of a background task.

Type Aliases

TaskId
Unique task identifier.