pub async fn canonical_root(cwd: &Path) -> Option<String>Expand description
Resolve the canonical repository root, following worktree links.
If the current directory is inside a worktree, this returns the path to the main repository (not the worktree checkout).