Git operation detection from command output.
Parses bash tool output to detect git commits, PR creates, branch operations, and other git events. Used for tracking and telemetry.
Structs
- GitOperation
- A detected git operation.
Enums
Functions
- detect_
git_ ops - Detect git operations from a command string and its output.